<?php

namespace Litecms\KycSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\KycSetting\Models\KycSettings;

class KycSettingsPolicy
{

    /**
     * Determine if the given user can view the kyc_settings.
     *
     * @param UserPolicy $user
     * @param KycSettings $kyc_settings
     *
     * @return bool
     */
    public function view(UserPolicy $user, KycSettings $kyc_settings)
    {
        if ($user->canDo('kyc_setting.kyc_settings.view') && $user->isAdmin()) {
            return true;
        }

        return $kyc_settings->user_id == user_id() && $kyc_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can create a kyc_settings.
     *
     * @param UserPolicy $user
     * @param KycSettings $kyc_settings
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('kyc_setting.kyc_settings.create');
    }

    /**
     * Determine if the given user can update the given kyc_settings.
     *
     * @param UserPolicy $user
     * @param KycSettings $kyc_settings
     *
     * @return bool
     */
    public function update(UserPolicy $user, KycSettings $kyc_settings)
    {
        if ($user->canDo('kyc_setting.kyc_settings.edit') && $user->isAdmin()) {
            return true;
        }

        return $kyc_settings->user_id == user_id() && $kyc_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given kyc_settings.
     *
     * @param UserPolicy $user
     * @param KycSettings $kyc_settings
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, KycSettings $kyc_settings)
    {
        return $kyc_settings->user_id == user_id() && $kyc_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given kyc_settings.
     *
     * @param UserPolicy $user
     * @param KycSettings $kyc_settings
     *
     * @return bool
     */
    public function verify(UserPolicy $user, KycSettings $kyc_settings)
    {
        if ($user->canDo('kyc_setting.kyc_settings.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given kyc_settings.
     *
     * @param UserPolicy $user
     * @param KycSettings $kyc_settings
     *
     * @return bool
     */
    public function approve(UserPolicy $user, KycSettings $kyc_settings)
    {
        if ($user->canDo('kyc_setting.kyc_settings.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
