<?php

namespace Litecms\KycSetting\Providers;

use Illuminate\Support\ServiceProvider;

class KycSettingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'kyc_setting');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'kyc_setting');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.kyc_setting', function ($app) {
            return $this->app->make('Litecms\KycSetting\KycSetting');
        });

                // Bind KycSettings to repository
        $this->app->bind(
            'Litecms\KycSetting\Interfaces\KycSettingsRepositoryInterface',
            \Litecms\KycSetting\Repositories\Eloquent\KycSettingsRepository::class
        );

        $this->app->register(\Litecms\KycSetting\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\KycSetting\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\KycSetting\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.kyc_setting'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/kyc_setting.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/kyc_setting')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/kyc_setting')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
